==> 1.0.1.tar.gz: lib/src/core/widgets/pickers/ModernFormTextMultiPicker.dart <==
part of modern_form_core;

class ModernFormMultiTextPicker<T> extends StatelessWidget {
  final String? label;
  final String? helperText;
  final String? buttonLabel;
  final List<String>? suggestions;
  final void Function(List<String?>)? onChangedSuggestions;
  final List<ModernFormBottomSheetModel<T>>? list;
  final void Function(List<T?>)? onChangedList;
  final bool? forceMenu;
  final bool? moveEnable;

  final List<String>? suggestionsValue;
  final List<ModernFormBottomSheetModel<T>>? listValue;
  final String? Function(List<String?>?)? validator;

  const ModernFormMultiTextPicker({
    Key? key,
    this.label,
    this.suggestions,
    this.list,
    this.forceMenu,
    this.onChangedList,
    this.onChangedSuggestions,
    this.suggestionsValue,
    this.listValue,
    this.buttonLabel,
    this.validator,
    this.helperText,
    this.moveEnable,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    List<String?>? itens = listValue?.map((e) => e.text).toList();
    List<String?>? initialValue = suggestionsValue ?? itens;
    List<String?> _suggestions =
        suggestions ?? list?.map((e) => e.text).toList() ?? <String>[];

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(label ?? "", style: ModernFormTextStyle.moderFormLabelStyle),
        helperText != null
            ? Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
                child: Text(helperText ?? "",
                    style: ModernFormTextStyle.moderFormHelperStyle),
              )
            : SizedBox(),
        validator != null && validator!(initialValue) != null
            ? Text(validator!(initialValue) ?? "",
                style: ModernFormTextStyle.moderFormErrorStyle)
            : Container(),
        ModernFormFilterWithCheckboxIten(
          initialValue: initialValue,
          bottomSheetLabelText: "Selecione",
          buttonText: buttonLabel ?? "Adicionar",
          forceMenu: forceMenu,
          suggestions: _suggestions,
          moveEnable: moveEnable,
          onChanged: (List<String?> selecteds) {
            if (onChangedSuggestions != null) {
              onChangedSuggestions!(selecteds);
            }
            if (onChangedList != null) {
              List<T?> _values = <T?>[];
              selecteds.forEach((element) {
                ModernFormBottomSheetModel<T>? v =
                    list!.firstWhereOrNull((e) => e.text == element);
                if (v != null) {
                  _values.add(v.value);
                }
              });
              onChangedList!(_values);
            }
          },
        ),
      ],
    );
  }
}

==> 1.0.6.tar.gz: lib/src/core/widgets/pickers/ModernFormTextMultiPicker.dart <==
part of modern_form_core;

class ModernFormMultiTextPicker<T> extends StatelessWidget {
  final String? label;
  final String? helperText;
  final String? buttonLabel;

  final bool? forceMenu;
  final bool? moveEnable;

  final List<ModernFormBottomSheetModel<T>> suggestions;
  final List<ModernFormBottomSheetModel<T>>? value;
  final void Function(List<T>)? onChanged;

  final String? Function(List<T>?)? validator;

  const ModernFormMultiTextPicker({
    Key? key,
    this.label,
    required this.suggestions,
    this.forceMenu,
    this.onChanged,
    this.value,
    this.buttonLabel,
    this.validator,
    this.helperText,
    this.moveEnable,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    List<T>? _value = value?.map((e) => e.value).toList();
    List<String> _suggestions = suggestions.map((e) => e.text).toList();

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(label ?? "", style: ModernFormTextStyle.moderFormLabelStyle),
        helperText != null
            ? Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
                child: Text(helperText!,
                    style: ModernFormTextStyle.moderFormHelperStyle),
              )
            : SizedBox(),
        validator != null && validator!(_value) != null
            ? Text(
                validator!(_value)!,
                style: ModernFormTextStyle.moderFormErrorStyle,
              )
            : SizedBox(),
        ModernFormFilterWithCheckboxIten(
          bottomSheetLabelText: "Selecione",
          buttonText: buttonLabel ?? "Adicionar",
          forceMenu: forceMenu,
          moveEnable: moveEnable,
          suggestions: suggestions,
          value: value,
          onChanged: onChanged,
        ),
      ],
    );
  }
}
